==> clementine-0.5.3.tar.gz: clementine-0.5.3/src/playlistparsers/asxiniparser.cpp <==
/* This file is part of Clementine.

   Clementine is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Clementine is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Clementine.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "asxiniparser.h"

#include <QTextStream>
#include <QtDebug>

AsxIniParser::AsxIniParser(QObject* parent)
  : ParserBase(parent)
{
}

bool AsxIniParser::TryMagic(const QByteArray &data) const {
  return data.toLower().contains("[reference]");
}

SongList AsxIniParser::Load(QIODevice *device, const QDir &dir) const {
  SongList ret;

  while (!device->atEnd()) {
    QString line = QString::fromUtf8(device->readLine()).trimmed();
    int equals = line.indexOf('=');
    QString key = line.left(equals).toLower();
    QString value = line.mid(equals + 1);

    if (key.startsWith("ref")) {
      Song song;
      if (!ParseTrackLocation(value, dir, &song))
        qWarning() << "Failed to parse location: " << value;
      ret << song;
    }
  }

  return ret;
}

void AsxIniParser::Save(const SongList &songs, QIODevice *device, const QDir &dir) const {
  QTextStream s(device);
  s << "[Reference]" << endl;

  int n = 1;
  foreach (const Song& song, songs) {
    s << "Ref" << n << "=" << MakeRelativeTo(song.filename(), dir) << endl;
    ++n;
  }
}

==> clementine_0.6.orig.tar.gz: clementine-0.6/src/playlistparsers/asxiniparser.cpp <==
/* This file is part of Clementine.
   Copyright 2010, David Sansome <me@davidsansome.com>

   Clementine is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Clementine is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Clementine.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "asxiniparser.h"

#include <QTextStream>
#include <QtDebug>

AsxIniParser::AsxIniParser(LibraryBackendInterface* library, QObject* parent)
  : ParserBase(library, parent)
{
}

bool AsxIniParser::TryMagic(const QByteArray &data) const {
  return data.toLower().contains("[reference]");
}

SongList AsxIniParser::Load(QIODevice *device, const QDir &dir) const {
  SongList ret;

  while (!device->atEnd()) {
    QString line = QString::fromUtf8(device->readLine()).trimmed();
    int equals = line.indexOf('=');
    QString key = line.left(equals).toLower();
    QString value = line.mid(equals + 1);

    if (key.startsWith("ref")) {
      Song song;
      if (!ParseTrackLocation(value, dir, &song))
        qWarning() << "Failed to parse location: " << value;

      // Load the song from the library if it's there.
      Song library_song = LoadLibrarySong(song.filename());
      if (library_song.is_valid())
        ret << library_song;
      else
        ret << song;
    }
  }

  return ret;
}

void AsxIniParser::Save(const SongList &songs, QIODevice *device, const QDir &dir) const {
  QTextStream s(device);
  s << "[Reference]" << endl;

  int n = 1;
  foreach (const Song& song, songs) {
    s << "Ref" << n << "=" << MakeRelativeTo(song.filename(), dir) << endl;
    ++n;
  }
}
